@@ -24,13 +24,13 @@
 
 import argparse
 import io
+import json
 import logging
 import sys
 from collections import defaultdict
 from pathlib import Path
 
 import jsonschema.exceptions
-import orjson as json
 from toolz import get, take
 
 from dbnomics_data_model import storages, validators
